# -*- coding: utf-8 -*-
# encoding: utf-8

# Gravaty
# Copyright © 2013  Marco Bresciani
#
# This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with this program. If not, see
# <http://www.gnu.org/licenses/>.

require '../lib/name/bresciani/marco/gravaty/gravaty'

a_gravaty = Gravaty.new 'user@example.com'

# prints the email
# (user@example.com).
puts '1. prints the email (user@example.com).'
puts a_gravaty.email
puts

# prints the MD5 digest of the downcased email address
# (b58996c504c5638798eb6b511e6f49af).
puts '2. prints the MD5 digest of the downcased email address (b58996c504c5638798eb6b511e6f49af).'
puts a_gravaty.digest
puts

# prints the secure URL for Gravatar retrieval
# (http://www.gravatar.com/avatar/b58996c504c5638798eb6b511e6f49af).
puts '3. prints the secure URL for Gravatar retrieval (http://www.gravatar.com/avatar/b58996c504c5638798eb6b511e6f49af).'
puts a_gravaty.image_request
puts a_gravaty.image_param_request
puts

# prints the basic URL for Gravatar retrieval, with no frills
# (https://secure.gravatar.com/avatar/b58996c504c5638798eb6b511e6f49af).
puts '4. prints the basic URL for Gravatar retrieval, with no frills (https://secure.gravatar.com/avatar/b58996c504c5638798eb6b511e6f49af).'
puts a_gravaty.image_request
puts a_gravaty.image_param_request nil, nil, false
puts

# prints the secure URL for Gravatar retrieval, with specified image file extension
# (http://www.gravatar.com/avatar/b58996c504c5638798eb6b511e6f49af.jpg).
puts '5. prints the secure URL for Gravatar retrieval, with specified image file extension (http://www.gravatar.com/avatar/b58996c504c5638798eb6b511e6f49af.jpg).'
puts a_gravaty.image_request({type: 'JPG'})
puts a_gravaty.image_param_request 'JPG'
puts

# prints the basic URL for Gravatar retrieval, with specified image file extension
# (https://secure.gravatar.com/avatar/b58996c504c5638798eb6b511e6f49af.GIF).
puts '6. prints the basic URL for Gravatar retrieval, with specified image file extension (https://secure.gravatar.com/avatar/b58996c504c5638798eb6b511e6f49af.GIF).'
puts a_gravaty.image_request({type: 'GIF', secure: false})
puts a_gravaty.image_param_request 'GIF', nil, false, false
puts

# prints the basic URL for Gravatar retrieval, with specified image size (in pixels) and specified image file extension
# (http://www.gravatar.com/avatar/b58996c504c5638798eb6b511e6f49af.png?s=42).
puts '7. prints the basic URL for Gravatar retrieval, with specified image size (in pixels) and specified image file extension (http://www.gravatar.com/avatar/b58996c504c5638798eb6b511e6f49af.png?s=42).'
puts a_gravaty.image_request({type: 'png', pixel_size: 42, secure: false})
puts a_gravaty.image_param_request 'PNG', 42, false, false
puts

# prints the basic URL for Gravatar retrieval, with specified image size (in pixels), specified image file extension and forced default
# (http://www.gravatar.com/avatar/b58996c504c5638798eb6b511e6f49af.png?s=42&f=y).
puts '8. prints the basic URL for Gravatar retrieval, with specified image size (in pixels), specified image file extension and forced default (http://www.gravatar.com/avatar/b58996c504c5638798eb6b511e6f49af.png?s=42&f=y).'
puts a_gravaty.image_request({type: 'png', pixel_size: 42, secure: false, force: true})
puts a_gravaty.image_param_request 'PNG', 42, true, false
puts
